weaviate
--------

.. automodule:: weaviate
   :members:
   :exclude-members: Client,BatchClient,ClientBatchingContextManager
   :undoc-members:
   :inherited-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   weaviate.backup
   weaviate.classes
   weaviate.cluster
   weaviate.collections
   weaviate.connect
   weaviate.debug
   weaviate.gql
   weaviate.outputs
   weaviate.rbac
   weaviate.users


weaviate.auth
^^^^^^^^^^^^^

.. automodule:: weaviate.auth
   :members:
   :undoc-members:
   :private-members:

weaviate.config
^^^^^^^^^^^^^^^

.. automodule:: weaviate.config
   :members:
   :undoc-members:

weaviate.embedded
^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.embedded
   :members:
   :undoc-members:
